==> haskell-with-utf8-1.1.0.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-FcNt1F3TdNE5f8EXGGSfM0
key:                  with-utf8-1.1.0.0-FcNt1F3TdNE5f8EXGGSfM0
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  6b7866f9bc8026f26e6ad3ef01294917
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-FcNt1F3TdNE5f8EXGGSfM0
depends:
    base-4.17.2.1 safe-exceptions-0.1.7.4-HUJdl4Kng6U4yyvkQ5SBPv
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-utf8-1.1.0.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-2hKwd2lvSpkCc5E8I4sCv4
key:                  with-utf8-1.1.0.0-2hKwd2lvSpkCc5E8I4sCv4
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  1e270f87efe7251b47f628250005c2d9
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-2hKwd2lvSpkCc5E8I4sCv4
depends:
    base-4.17.2.1 safe-exceptions-0.1.7.4-8SsW7I1Sl702u8ubZl6Ww1
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
